pub struct Encoder<R: Read> { /* private fields */ }Expand description
Streaming compression for input streams implementing std::io::Read.
Notes
One should consider using crate::compress or crate::compress_into if possible.
In that context, we do not need to hold and maintain intermediate buffers for reading and writing.
Example
use std::{io, io::Read};
use isal::{read::Encoder, CompressionLevel, decompress, Codec};
let data = b"Hello, World!".to_vec();
let mut encoder = Encoder::new(data.as_slice(), CompressionLevel::Three, Codec::Gzip);
let mut compressed = vec![];
// Number of compressed bytes written to `output`
let n = io::copy(&mut encoder, &mut compressed).unwrap();
assert_eq!(n as usize, compressed.len());
let decompressed = decompress(compressed.as_slice(), Codec::Gzip).unwrap();
assert_eq!(decompressed.as_slice(), data);Implementations
Sourceimpl<R: Read> Encoder<R>
impl<R: Read> Encoder<R>
Sourcepub fn new(reader: R, level: CompressionLevel, codec: Codec) -> Encoder<R> ⓘ
pub fn new(reader: R, level: CompressionLevel, codec: Codec) -> Encoder<R> ⓘ
Create a new Encoder which implements the std::io::Read trait.
Sourcepub fn get_ref_mut(&mut self) -> &mut R
pub fn get_ref_mut(&mut self) -> &mut R
Mutable reference to underlying reader, not advisable to modify during reading.
pub fn get_ref(&self) -> &R