pub struct Decoder<W: Write> { /* private fields */ }Expand description
Streaming compression for input streams implementing std::io::Write.
Notes
One should consider using crate::decompress or crate::decompress_into if possible.
In that context, we do not need to hold and maintain intermediate buffers for reading and writing.
Example
use std::{io, io::Write};
use isal::{write::Decoder, CompressionLevel, compress, Codec};
let data = b"Hello, World!".to_vec();
let compressed = compress(io::Cursor::new(data.as_slice()), CompressionLevel::Three, Codec::Gzip).unwrap();
let mut decompressed = vec![];
let mut decoder = Decoder::new(&mut decompressed, Codec::Gzip);
// Numbeer of compressed bytes written to `output`
let n = io::copy(&mut io::Cursor::new(&compressed), &mut decoder).unwrap();
assert_eq!(n as usize, compressed.len());
assert_eq!(decompressed.as_slice(), data);Implementations