pub struct Encoder<W: Write> { /* private fields */ }Expand description
Streaming compression for input streams implementing std::io::Write.
Notes
One should consider using crate::compress or crate::compress_into if possible.
In that context, we do not need to hold and maintain intermediate buffers for reading and writing.
Example
use std::{io, io::Write};
use isal::{write::Encoder, CompressionLevel, decompress, Codec};
let data = b"Hello, World!".to_vec();
let mut compressed = vec![];
let mut encoder = Encoder::new(&mut compressed, CompressionLevel::Three, Codec::Gzip);
// Numbeer of compressed bytes written to `output`
io::copy(&mut io::Cursor::new(&data), &mut encoder).unwrap();
// call .flush to finish the stream
encoder.flush().unwrap();
let decompressed = decompress(io::Cursor::new(&compressed), Codec::Gzip).unwrap();
assert_eq!(decompressed.as_slice(), data);
Implementations
Sourceimpl<W: Write> Encoder<W>
impl<W: Write> Encoder<W>
Sourcepub fn new(writer: W, level: CompressionLevel, codec: Codec) -> Encoder<W> ⓘ
pub fn new(writer: W, level: CompressionLevel, codec: Codec) -> Encoder<W> ⓘ
Create a new Encoder which implements the std::io::Read trait.
Sourcepub fn get_ref_mut(&mut self) -> &mut W
pub fn get_ref_mut(&mut self) -> &mut W
Mutable reference to underlying reader, not advisable to modify during reading.
pub fn get_ref(&self) -> &W