pub struct ZlibEncoder<R: Write> { /* private fields */ }Expand description
Zlib compression
Basically a wrapper to Encoder which sets the codec for you.
Implementations
Sourceimpl<W: Write> ZlibEncoder<W>
impl<W: Write> ZlibEncoder<W>
pub fn new(writer: W, level: CompressionLevel) -> Self
Sourcepub fn get_ref_mut(&mut self) -> &mut W
pub fn get_ref_mut(&mut self) -> &mut W
Mutable reference to underlying reader, not advisable to modify during reading.
pub fn get_ref(&self) -> &W